@@ -26,24 +26,25 @@ NAME = APIS['facebook']
 DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
 DATETIME_FORMAT_NEW = '%d %B %Y'
 
-URL = 'https://fiapi.nl:8080/facebook_post/'
+URL = 'https://fi-api.io/facebook_post/'
+BASE_URL_IMAGES = 'https://socials-bucket.s3.eu-central-1.amazonaws.com'
+
+XML_FILENAME = 'facebook.xml'
 
 
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(api_key, page_name, max_minutes, max_characters, max_items):
+def run_api(api_key, max_minutes, max_characters, max_items):
     max_file_age = 60 * max_minutes
-    filename = '{}.xml'.format(page_name.lower())
-    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, filename)
+    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
 
     headers = {
         'Authorization': 'Token {}'.format(api_key)
     }
 
     params = {
-        'page_name': page_name,
         'number_of_posts': max_items
     }
 
@@ -57,16 +58,14 @@ def run_api(api_key, page_name, max_minutes, max_characters, max_items):
 
         for post in response_json:
             item = ET.SubElement(root, "item")
-            ET.SubElement(item, "page_name").text = get_page_name(post)
-            ET.SubElement(item, "likes").text = str(get_likes(post))
+            ET.SubElement(item, "likes").text = str(get_reactions(post)['likes'])
             ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters)
             ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, DATETIME_FORMAT_NEW)
 
-            thumbnail_url = get_thumbnail_url(post)
+            thumbnail_url = get_image(post)
             if thumbnail_url is None:
                 media_link = 'Content:\\placeholders\\img.png'
             else:
-                thumbnail_url = thumbnail_url.split('?').pop(0)
                 media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
             
             ET.SubElement(item, "image").text = media_link
@@ -75,12 +74,12 @@ def run_api(api_key, page_name, max_minutes, max_characters, max_items):
     else:
         log(NAMELEVEL['INFO'], 'File not old enough to download new info')
 
-def check_api(page_name, max_minutes):
+def check_api(max_minutes):
     svars = variables()
 
     max_file_age = 60 * max_minutes
 
-    file_name = '{}*.xml'.format(page_name.lower())
+    file_name = 'facebook*.xml'
     file_path = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, file_name)
 
     file_path = glob.glob(file_path)[0]
@@ -99,24 +98,21 @@ def check_api(page_name, max_minutes):
 # GET FUNCTIONS
 ##################################################################################################
 
-def get_page_name(post):
-    return post['page_name']
-
-
-def get_thumbnail_url(post):
-    return post['thumbnail']
-
-
-def get_likes(post):
-    return post['likes']
+def get_image(post):
+    return post.get('image', None)
 
+def get_reactions(post):
+    return post.get('reactions', {})
 
 def get_message(post):
-    return post['message']
-
+    return post.get('message', '')
 
 def get_creation_date(post):
-    return post['created_at'][:-6]
+    creation_date = post.get('created_at', None)
+    if creation_date is None:
+        return None
+    else:
+        return creation_date[:19]
 
 ##################################################################################################
 # PARSE FUNCTIONS
